##
##  autoconf.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   version numbers
%define       V_latest       2.72
%define       V_latest_comp  272
%define       V_older        2.59
%define       V_older_comp   259
%define       V_ancient      2.13
%define       V_ancient_comp 213

#   package information
Name:         autoconf
Summary:      GNU Source Autoconfiguration
URL:          http://www.gnu.org/software/autoconf/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        CORE
Group:        Building
License:      GPL
Version:      %{V_latest}
Release:      20231224

#   list of sources
Source0:      http://ftp.gnu.org/gnu/autoconf/autoconf-%{V_latest}.tar.gz
Source1:      http://ftp.gnu.org/gnu/autoconf/autoconf-%{V_older}.tar.gz
Source2:      http://ftp.gnu.org/gnu/autoconf/autoconf-%{V_ancient}.tar.gz
Patch0:       autoconf.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, m4 >= 1.4, perl, make
PreReq:       OpenPKG, openpkg >= 20160101, m4 >= 1.4, perl

%description
    Autoconf is an extensible package of m4 macros that produce shell
    scripts to automatically configure software source code packages.
    These scripts can adapt the packages to many kinds of UNIX-like
    systems without manual user intervention. Autoconf creates a
    configuration script for a package from a template file that lists
    the operating system features that the package can use, in the form
    of m4 macro calls.

    This OpenPKG packages provides the following Autoconf versions:
    - GNU Autoconf %{V_latest} (latest version, the default)
    - GNU Autoconf %{V_older} (older version, as an alternative)
    - GNU Autoconf %{V_ancient} (ancient version, for backward-compatibility)

%track
    prog autoconf = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/autoconf/
        regex     = autoconf-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c -n autoconf-%{V_latest}
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2
    %patch -p0

%build
    #   configure and build Autoconf (deprecated version)
    ( cd autoconf-%{V_ancient}
      CC="%{l_cc}" \
      CFLAGS="%{l_cflags -O}" \
      ./configure \
          --prefix=%{l_prefix} \
          --program-suffix="-%{V_ancient_comp}"
      %{l_shtool} subst \
          -e 's;\(acdatadir = $(datadir)/autoconf\);\1/%{V_ancient_comp};' \
          Makefile
      %{l_make} %{l_mflags}
    ) || exit $?

    #   configure and build Autoconf (older version)
    ( cd autoconf-%{V_older}
      %{l_shtool} subst \
          -e 's;^\(PACKAGE_STRING=.GNU Autoconf [0-9.]*\)\(.\);\1 (%{l_openpkg_release})\2;g' \
          configure
      %{l_shtool} subst \
          -e 's;^\(pkgdatadir.=..(datadir)\)/@PACKAGE@;\1;' \
          Makefile.in */Makefile.in */*/Makefile.in
      CC="%{l_cc}" \
      CFLAGS="%{l_cflags -O}" \
      ACLOCAL=true \
      AUTOMAKE=true \
      AUTOCONF=true \
      AUTOHEADER=true \
      MAKEINFO=true \
      GREP=grep \
      ./configure \
          --prefix=%{l_prefix} \
          --datadir=%{l_prefix}/share/autoconf/%{V_older_comp} \
          --program-suffix="-%{V_older_comp}"
      %{l_make} %{l_mflags}
    ) || exit $?

    #   configure and build Autoconf (current version)
    ( cd autoconf-%{V_latest}
      %{l_shtool} subst \
          -e 's;^\(PACKAGE_STRING=.GNU Autoconf [0-9.]*\)\(.\);\1 (%{l_openpkg_release})\2;g' \
          configure
      %{l_shtool} subst \
          -e 's;^\(pkgdatadir.=..(datadir)\)/@PACKAGE@;\1;' \
          Makefile.in */Makefile.in */*/Makefile.in
      CC="%{l_cc}" \
      CFLAGS="%{l_cflags -O}" \
      ACLOCAL=true \
      AUTOMAKE=true \
      AUTOCONF=true \
      AUTOHEADER=true \
      MAKEINFO=true \
      GREP=grep \
      ./configure \
          --prefix=%{l_prefix} \
          --mandir=%{l_prefix}/man \
          --datadir=%{l_prefix}/share/autoconf/%{V_latest_comp} \
          --infodir=%{l_prefix}/info
      %{l_make} %{l_mflags}
    ) || exit $?

%install

    #   configure and build Autoconf (deprecated version)
    ( cd autoconf-%{V_ancient}
      %{l_make} %{l_mflags} install \
          prefix=$RPM_BUILD_ROOT%{l_prefix}
      mv $RPM_BUILD_ROOT%{l_prefix}/info/autoconf.info \
         $RPM_BUILD_ROOT%{l_prefix}/info/autoconf-%{V_ancient_comp}.info
    ) || exit $?

    #   configure and build Autoconf (older version)
    ( cd autoconf-%{V_older}
      %{l_make} %{l_mflags} install \
          prefix=$RPM_BUILD_ROOT%{l_prefix} \
          datadir=$RPM_BUILD_ROOT%{l_prefix}/share/autoconf/%{V_older_comp} \
          mandir=$RPM_BUILD_ROOT%{l_prefix}/man \
          infodir=$RPM_BUILD_ROOT%{l_prefix}/info
      mv $RPM_BUILD_ROOT%{l_prefix}/info/autoconf.info \
         $RPM_BUILD_ROOT%{l_prefix}/info/autoconf-%{V_older_comp}.info
    ) || exit $?

    #   configure and build Autoconf (current version)
    ( cd autoconf-%{V_latest}
      %{l_make} %{l_mflags} install \
          prefix=$RPM_BUILD_ROOT%{l_prefix} \
          datadir=$RPM_BUILD_ROOT%{l_prefix}/share/autoconf/%{V_latest_comp} \
          mandir=$RPM_BUILD_ROOT%{l_prefix}/man \
          infodir=$RPM_BUILD_ROOT%{l_prefix}/info
    ) || exit $?

    #   strip down installation
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/xemacs
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

